# Author: Theophanis Tsandilas

rm(list=ls())
library(plotrix)
library(nlme) #Library for Linear Mixel Effect Models
library(ez) #Library for ezANOVA

#read the data from a csv file
data <- read.csv(file="IQ-tests.csv", header=TRUE, sep=",")

#############################################
#############################################
# ANOVA, assuming that assumptions are all valid
# Finally, conduct an analysis of variance
# You need to treat participant as a factor variable: https://www.guru99.com/r-factor-categorical-continuous.html
anovaModel <- aov(score ~ group*week + Error(factor(participant)/week), data)
anovaResult <- summary(anovaModel)
cat("Conduct an ANOVA  with mixed measures: week is a repeated measures and group is between-participants variable\n")
print(anovaResult)

#http://www.dwoll.de/rexrepos/posts/anovaMixed.html
lmeModel <- lme(score ~ week*group, random= ~1|participant, data=data)
lmeResult <- anova(lmeModel)
cat("Conduct a Linear Mixed-Effect Model: week is a repeated measures and group is between-participants variable\n")
print(lmeResult)

# If we are further interested in generalized eta square estimates (effect size measures)
# we can use the ezANOVA function in the ez package
# In case the sphericity assumption are violated (required for repeated measures desings),
# this function will also run Mauchcly's test for sphericity and will obtain sphericity corrections
# See: https://people.umass.edu/bwdillon/LING609/Lectures/Section3/Lecture21.html
anova2 <- ezANOVA(data = data, dv=.(score), wid=.(participant), within=.(week), between=.(group))
cat("Conduct the ANOVA with ezANOVA (ges = generalized eta square)\n")
print(anova2)

# PLOTS
########################################
#######################################
# Control: split the aggregated data into three groups
cdata <- data[data$group=="control",]

cdata.w1 <- cdata[cdata$week==1,]
cdata.w2 <- cdata[cdata$week==2,]
cdata.w3 <- cdata[cdata$week==3,]

# calculate the means
cmean.w1 <- mean(cdata.w1$score)
cmean.w2 <- mean(cdata.w2$score)
cmean.w3 <- mean(cdata.w3$score)

# construct individual CIs
cci.w1 <- t.test(cdata.w1$score)$conf.int
cci.w2 <- t.test(cdata.w2$score)$conf.int
cci.w3 <- t.test(cdata.w3$score)$conf.int

# Geometry: split the aggregated data into three groups
gdata <- data[data$group=="geometry",]

gdata.w1 <- gdata[gdata$week==1,]
gdata.w2 <- gdata[gdata$week==2,]
gdata.w3 <- gdata[gdata$week==3,]

# calculate the means
gmean.w1 <- mean(gdata.w1$score)
gmean.w2 <- mean(gdata.w2$score)
gmean.w3 <- mean(gdata.w3$score)

# construct individual CIs
gci.w1 <- t.test(gdata.w1$score)$conf.int
gci.w2 <- t.test(gdata.w2$score)$conf.int
gci.w3 <- t.test(gdata.w3$score)$conf.int

# We need to plot two graphs in two columns
par(mfrow=c(1,2), mar = c(2.5,1.5,0,0), pty='s')

##########################
#CIs and trends for control and geometry groups
plotCI(c(1, 2, 3), c(cmean.w1, cmean.w2, cmean.w3),
    ui=c(cci.w1[2], cci.w2[2], cci.w3[2]),
    li=c(cci.w1[1], cci.w2[1], cci.w3[1]),
    pch=4, xlab=NA, xaxt='n', xlim=c(.5, 3.5), ylab="Mean IQ Score", sfrac=0, col="green4", lwd = 1.2, bty="n")
lines(c(1, 2, 3), c(cmean.w1, cmean.w2, cmean.w3), col="green4", lwd = 1.2)

#overplot CIs of geometry group (a little bit to the left to avoid overlapping)
plotCI(c(0.95, 1.95, 2.95), c(gmean.w1, gmean.w2, gmean.w3),
    ui=c(gci.w1[2], gci.w2[2], gci.w3[2]),
    li=c(gci.w1[1], gci.w2[1], gci.w3[1]),
    pch=1, xlab=NA, xaxt='n', xlim=c(.5, 3.5), ylab=NA, sfrac=0, add=TRUE, col="orange2", lwd = 1.2, bty="n")
lines(c(0.95, 1.95, 2.95), c(gmean.w1, gmean.w2, gmean.w3), col="orange2", lwd = 1.2)

text(1.4, 107, "Geometry", col="orange3")
text(1.4, 90, "Control", col="green4")
axis(1, at = 1:3, labels = c("Week 1", "Week 2", "Week 3"))
segments(0, 100, 3, 100, lty=2, col="grey")

##########################
# CIs for mean differences - independent groups
diffci.w1 <- t.test(gdata.w1$score, cdata.w1$score)$conf.int
diffci.w2 <- t.test(gdata.w2$score, cdata.w2$score)$conf.int
diffci.w3 <- t.test(gdata.w3$score, cdata.w3$score)$conf.int

# And plot them
plotCI(c(1, 2, 3), c(gmean.w1 - cmean.w1, gmean.w2 - cmean.w2, gmean.w3 - cmean.w3),
    ui=c(diffci.w1[2], diffci.w2[2], diffci.w3[2]),
    li=c(diffci.w1[1], diffci.w2[1], diffci.w3[1]),
    pch=20, xlab=NA, xaxt='n', xlim=c(.5, 3.5), ylab="Mean IQ Score Difference", sfrac=0, col="blue", lwd = 1.2, bty="n")
lines(c(1, 2, 3), c(gmean.w1 - cmean.w1, gmean.w2 - cmean.w2, gmean.w3 - cmean.w3), col="blue", lwd = 1.2)
axis(1, at = 1:3, labels = c("Week 1", "Week 2", "Week 3"))
segments(0, 0, 3, 0, lty=2, col="grey")



